2.018.20: add a few functions that have changed signature to the unintern list,
authorFrancois-Rene Rideau <fare@tunes.org>
Mon, 21 Nov 2011 21:53:30 +0000 (16:53 -0500)
committerFrancois-Rene Rideau <fare@tunes.org>
Mon, 21 Nov 2011 21:53:30 +0000 (16:53 -0500)
for smoother upgrade. Update web page.

asdf.asd
asdf.lisp
doc/index.html

index 14b6bea..73088a4 100644 (file)
--- a/asdf.asd
+++ b/asdf.asd
@@ -14,7 +14,7 @@
   :licence "MIT"
   :description "Another System Definition Facility"
   :long-description "ASDF builds Common Lisp software organized into defined systems."
-  :version "2.018.19" ;; to be automatically updated by bin/bump-revision
+  :version "2.018.20" ;; to be automatically updated by bin/bump-revision
   :depends-on ()
   :components
   ((:file "asdf")
index 40a1106..7f2c9bf 100644 (file)
--- a/asdf.lisp
+++ b/asdf.lisp
@@ -1,5 +1,5 @@
 ;;; -*- mode: Common-Lisp; Base: 10 ; Syntax: ANSI-Common-Lisp -*-
;;; This is ASDF 2.018.19: Another System Definition Facility.
 ;;;
 ;;; Feedback, bug reports, and patches are all welcome:
 ;;; please mail to <asdf-devel@common-lisp.net>.
          ;; "2.345.6" would be a development version in the official upstream
          ;; "2.345.0.7" would be your seventh local modification of official release 2.345
          ;; "2.345.6.7" would be your seventh local modification of development version 2.345.6
-         (asdf-version "2.018.19")
+         (asdf-version "2.018.20")
          (existing-asdf (find-class 'component nil))
          (existing-version *asdf-version*)
          (already-there (equal asdf-version existing-version)))
            :unintern
            (#:*asdf-revision* #:around #:asdf-method-combination
             #:split #:make-collector #:do-dep #:do-one-dep
+            #:resolve-relative-location-component #:resolve-absolute-location-component
             #:output-files-for-system-and-operation) ; obsolete ASDF-BINARY-LOCATION function
            :export
            (#:defsystem #:oos #:operate #:find-system #:locate-system #:run-shell-command
index 9172c07..224c1d0 100644 (file)
@@ -19,6 +19,7 @@
         <li><a href="#what_it_is">What it is</a></li>
         <li><a href="#what_it_is_not">What it is not</a></li>
         <li><a href="#implementations">Supported Implementations</a></li>
+        <li><a href="#examples">Examples</a></li>
         <li><a href="#documentation">Documentation</a></li>
         <li><a href="#downloads">Getting it</a></li>
         <li><a href="#bugs">Reporting Bugs</a></li>
     <div class="contents">
         <a id="ASDF 2"></a>
         <h3>ASDF 2</h3>
-        <p>We released ASDF 2 on May 31st 2010.
-          It has since been widely adopted by the CL community.
+        <p>ASDF 2, initially released on May 31st 2010,
+          is the current successor of Daniel Barlow's ASDF,
+          made more portable and more robust, with a somewhat improved API.
+          It has since been widely adopted by the CL community,
+          and is actively maintained.
         </p>
         <a id="what_it_is"></a>
         <h3>What it is</h3>
         </p>
         <a id="what_it_is_not"></a>
         <h3>What it is not</h3>
-        <p>ASDF will not download missing software components for you.
+        <p>ASDF will <em>not</em> download missing software components for you.
           For that, you want <a href="http://quicklisp.org/">Quicklisp</a>,
           that builds upon ASDF, and is great for pulling and installing
           tarballs of packages you may depend upon;
           we also recommend <a href="http://common-lisp.net/project/clbuild/">clbuild</a>,
           that now builds upon Quicklisp, as a great tool for pulling from version control
           packages you need to modify or want to contribute to.
-          We recommend you should not use ASDF-Install anymore,
-          as it is another such piece of software that is both unmaintained and obsolete.
+          We recommend you should <em>not</em> use ASDF-Install anymore,
+          as it is an older similar piece of software that is both unmaintained and obsolete.
+        </p><p>
+          If you're unsatisfied with ASDF, other actively maintained build systems for Common-Lisp
+          that may or may not satisfy you include:
+          Fran&ccedil;ois-Ren&eacute; Rideau's
+          <a href="http://common-lisp.net/project/xcvb/">XCVB</a>
+          (trying to build object and image files deterministically and in parallel),
+          or its polar opposite,
+          Drew McDermott's
+          <a href="http://cs-www.cs.yale.edu/homes/dvm/">YTools</a>
+          (trying maintain coherence of the current Lisp image at a fine grain).
+          Older systems that are not maintained anymore include
+          Mark Kantrowitz's <a href="http://www.cliki.net/mk-defsystem">mk-defsystem</a>
+          (free software successor of the old proprietary DEFSYSTEM's and predecessor of ASDF),
+          Sean Ross's <a href="http://sean-ross.blogspot.com/search/label/mudballs">mudballs</a>
+          (aborted attempt at making things cleaner than in ASDF),
+          Peter Jetter's <a href="http://www.cliki.net/faslpath">faslpath</a>
+          (a much simpler system integrating mapping packages to files),
+          Alexander Kahl's <a href="http://www.cliki.net/evol">evol</a>
+          (a reimplementation of the GNU autotools stack in Lisp),
+          and probably more.
+          However, none of these systems seems to ever have had the traction of ASDF.
         </p>
         <a id="implmementations"></a>
         <h3>Supported Implementations</h3>
           that seem to have any current user base.
         </p><p>
           Most implementations provide ASDF 2 as a module,
-          and you can simply <tt>(require "asdf")</tt> or <tt>(require :asdf)</tt>.
-          Note that most implementations accept
-          <tt>:asdf</tt>, <tt>"ASDF"</tt> and <tt>"asdf"</tt>
-          indiscriminately, but that there are exceptions:
-          CLISP accepts only lower-case
-          (in a string, or a properly escaped lower-case symbol),
-          whereas unless you use a recent version from June 2011 or later,
-          CMUCL accepts only upper-case (or a case-converted symbol).
+          and you can simply <tt>(require "asdf")</tt>.
+          (All of them but CLISP also accept
+          <tt>:asdf</tt>, <tt>"ASDF"</tt> or <tt>'asdf</tt> as an argument.)
         </p><p>
           A few implementations don't provide ASDF yet,
           but have announced they will in their next release.
@@ -112,10 +132,16 @@ Peter Graves <gnooth@gmail.com>
           -->
         <p>
           If there is an old or new implementation that we are missing,
-          it shouldn't hard to adapt ASDF to support it.
+          it shouldn't be hard to adapt ASDF to support it.
           Ask us!
         </p>
 
+        <a id="examples"></a>
+        <h3>Examples</h3>
+        <p>Download any of the many packages available through
+          <a href="http://quicklisp.org/">Quicklisp</a>
+          to see as many examples.</p>
+
         <a id="documentation"></a>
         <h3>Documentation</h3>
         <p>You can read our manual:</p>
@@ -125,7 +151,8 @@ Peter Graves <gnooth@gmail.com>
           <li><a href="asdf.pdf">as a PDF document</a></li>
           <li><a href="http://common-lisp.net/gitweb?p=projects/asdf/asdf.git;a=blob;f=doc/asdf.texinfo">as texinfo source</a></li>
         </ul>
-        <p>Regarding the internal design of ASDF in general and the work we did on ASDF 2,
+        <p>Regarding the internal design of ASDF in general,
+          and the work we did on ASDF 2,
           see the last draft version of our paper for
           <a href="http://www.international-lisp-conference.org/2010/index">ILC 2010</a>,
           <cite><a href="ilc2010draft.pdf"
@@ -235,7 +262,7 @@ Peter Graves <gnooth@gmail.com>
         <a class="nav" href="http://common-lisp.net/" title="Common-Lisp.net"> <img src="http://common-lisp.net/project/cl-containers/shared/buttons/lisp-lizard.png" width="80" height="15" title="Common-Lisp.net" alt="Common-Lisp.net button" /></a>
         <p><span class="copyright"Copyright &copy; 2001-2011 Daniel Barlow and contributors</span></p>
         <p>ASDF has an <a href="http://www.opensource.org/licenses/mit-license.php">MIT style</a> license</p>
-        <div id="timestamp">Last updated 2011-06-18</div>
+        <div id="timestamp">Last updated 2011-11-21</div>
     </div>
   </body>
 </html>
@@ -1,5 +1,5 @@
 ;;; -*- mode: Common-Lisp; Base: 10 ; Syntax: ANSI-Common-Lisp -*-
-;;; This is ASDF 2.018.19: Another System Definition Facility.
+;;; This is ASDF 2.018.20: Another System Definition Facility.
 ;;;
 ;;; Feedback, bug reports, and patches are all welcome: